globals
[;parameters during selection
  extension-workers-move-selection-threshold
  extension-workers-selection-threshold
  kebele-administrators-move-selection-threshold
  kebele-administrators-selection-threshold
  perception-watershed-move-selection
  perception-watershed-selection-threshold

 ;parameters during campaign participation
  w-perceived-performance-kebele-administrator-campaign
  w-off-farm-participation-campaign
  w-distance-watershed-campaign
  w-education-campaign
  w-social-capital-campaign
  w-degree-participation-local-organizations-campaign
  w-perception-watershed-campaign
  extension-workers-move-campaign-threshold
  kebele-administrators-move-campaign-threshold
  chance-measure-campaign
  perception-influence-neighbor-threshold

 ;parameters during maintenance participation
  w-perceived-performance-kebele-administrator-maintenance
  w-off-farm-participation-maintenance
  w-distance-watershed-maintenance
  w-degree-participation-local-organizations-maintenance
  w-perception-watershed-maintenance
  extension-workers-move-maintenance-threshold
  kebele-administrators-move-maintenance-threshold
  maintenance-threshold
  demolition-threshold
  min-members-commitment-threshold
  max-members-commitment-threshold
  min-social-relation-threshold
  max-social-relation-threshold
  chance-measure-maintenance

  ;case study name monitor
  case-study-name
]

breed          [ farmers  farmer ]
breed          [ extension-workers  extension-worker ]
breed          [ kebele-administrators kebele-administrator ]

patches-own [                        ; each patch is 0.25 ha
  slope                              ; maximum 120%
  land-use                           ; communal land or farmland
  communal-micro-watershed?          ; true/false
  farmland-micro-watershed?          ; true/false
  micro-watershed-name               ; initial, 0, 1, 2, etc
  communal-SWC-cover?                ; true/false
  farmland-SWC-cover?                ; true/false
  quality-SWC                        ; 0-10
  owned-by                           ; which farmer owns this field
  ]

farmers-own [
  own-farmland                               ; group of fields on farmland that this farmer owns
  education                                  ; years, normally distributed
  extent-off-farm-participation              ; score, normally distributed
  degree-participation-local-organizations   ; score, normally distributed
  perceived-performance-kebele-administrator ; score, normally distributed
  income                                     ; birr, normally distributed and change in income is related only to CBWM program
  income-own-watershed                       ; birr, income that farmers earn from SWC on communal land
  income-own-farmland                        ; birr, income that farmers earn from SWC on farmland
  social-capital                             ; score, normally distributed
  perception-watershed                       ; score, normally distributed
  membership-watershed-association            ; yes/no
  own-watershed                              ; group of fields on communal land that this farmer owns as a member of this association
  commitment-member-micro-watershed          ; score, normally distributed only for members of micro-watersheds
  measure                                     ; praise, no measure,  aware, reprimand, punish
  campaign-participation                     ; calc. from attributes of farmers and their interactions
  maintenance-participation                  ; calc. from  attributes of farmers and their interactions
  ]

;;;;;;;;;;;;;;;;;SETUP;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;SETUP;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;SETUP;;;;;;;

to setup
 clear-all
 if new-seed? [ set current-seed new-seed ]
 random-seed current-seed
 set-parameters-selection
 set-parameters-campaign
 set-parameters-maintenance
 setup-patches-and-turtles
 set-case-study-name
 reset-ticks
end

to set-parameters-selection
 set extension-workers-move-selection-threshold 3
 set extension-workers-selection-threshold 7
 set kebele-administrators-move-selection-threshold 3
 set kebele-administrators-selection-threshold 6
 set perception-watershed-move-selection 5
 set perception-watershed-selection-threshold 7
end

to set-parameters-campaign
 ;same for all case studies
 set w-perceived-performance-kebele-administrator-campaign 0.242
 set w-off-farm-participation-campaign 0.385
 set w-distance-watershed-campaign 0.096
 set w-education-campaign 0.141
 set w-social-capital-campaign 0.085
 set w-degree-participation-local-organizations-campaign 0.039
 set w-perception-watershed-campaign 0.012
 set extension-workers-move-campaign-threshold 5
 set kebele-administrators-move-campaign-threshold 7
 set chance-measure-campaign 90
 set perception-influence-neighbor-threshold 9
end

to set-parameters-maintenance
 ;same for all case studies
 set w-perceived-performance-kebele-administrator-maintenance 0.289
 set w-off-farm-participation-maintenance 0.385
 set w-distance-watershed-maintenance 0.104
 set w-degree-participation-local-organizations-maintenance 0.022
 set w-perception-watershed-maintenance 0.200
 set extension-workers-move-maintenance-threshold 8
 set kebele-administrators-move-maintenance-threshold 8
 set maintenance-threshold 9
 set demolition-threshold 3
 set min-members-commitment-threshold 3
 set max-members-commitment-threshold 8
 set min-social-relation-threshold 3
 set max-social-relation-threshold 8
 set chance-measure-maintenance 80
end

to setup-patches-and-turtles
 ask patches [
 set slope false
 set land-use false
 set communal-micro-watershed? false
 set farmland-micro-watershed? false
 set communal-SWC-cover? false
 set farmland-SWC-cover? false
 set quality-SWC false
 set owned-by false
 set micro-watershed-name false
  ]

;assign slope to the landscape and diffuse
ask patches [let slope1 120 - distancexy -60 80
             let slope2 120 - distancexy 85 75

    ifelse slope1 > slope2 [set slope slope1] [set slope slope2]

;assign land-use based on slope
    ifelse slope > 30 [set land-use "communal-land" set pcolor cyan]
                      [set land-use "farmland" set pcolor orange]
    ]

;initialize number of micro-watersheds on communal land
ask n-of num-communal-micro-watershed patches with [land-use = "communal-land"] [
    set communal-micro-watershed? true
    set micro-watershed-name "initial"
    set pcolor lime
ask neighbors4 [ask patches with [pcolor = cyan] in-radius 2.5 [
    set communal-micro-watershed? true
    set micro-watershed-name "initial"
    set pcolor lime
      ]
    ]
  ]

;initialize area and quality of SWC on communal land
;width of SWC = 0.001 km, initial-length-SWC-communal-land is in km, 100 * 4 is to convert km2 to 0.25 ha, and
;average recommended SWC on communal land per hectare is 0.15 ha
let initial-communal-SWC-cover (0.001 * initial-length-SWC-communal-land * 100 * 4) / 0.15
ask n-of initial-communal-SWC-cover patches with [communal-micro-watershed? = true]
  [set communal-SWC-cover? true
   set quality-SWC random-normal average-quality-SWC 1.5
   set pcolor scale-color pink quality-SWC 10 0]

;initialize number of micro-watersheds on farmland
ask n-of num-farmland-micro-watershed patches with [land-use = "farmland"] [
    set farmland-micro-watershed? true
    set micro-watershed-name "initial"
    set pcolor gray

ask neighbors4 [ask patches with [pcolor = orange] in-radius 2.5 [
    set farmland-micro-watershed? true
    set micro-watershed-name "intitial"
    set pcolor gray]
    ]
  ]

;initialize area and quality of SWC on farmland
;width of SWC = 0.001 km, initial-length-SWC-farmland is in km, 100 * 4 is to convert km2 to 0.25 ha, and
;average recommended SWC on farmland per hectare is 0.11 ha
let initial-farmland-SWC-cover (0.001 * initial-length-SWC-farmland * 100 * 4) / 0.11
ask n-of initial-farmland-SWC-cover patches with [farmland-micro-watershed? = true]
  [set farmland-SWC-cover? true
   set quality-SWC random-normal average-quality-SWC 1.5
   set pcolor scale-color pink quality-SWC 10 0]

create-extension-workers number-of-extension-workers [
    setxy 2 2
    set shape "person"
    set color blue
    set size 1
    ]

create-kebele-administrators 1 [
    setxy 1 1
    set shape "person"
    set color red - 2
    set size 1
   ]

create-farmers number-of-farmers [
    move-to one-of patches with [slope <= 30]
    if any? other farmers-here [move-to one-of patches with [slope <= 30 and not any? farmers-here]]
    set shape "person"
    set color 9.9
    set size 0.75
    set membership-watershed-association false
    set own-watershed false
   ]

 ask n-of (proportion-of-members-watershed * count farmers) farmers [
    set membership-watershed-association true
    set own-watershed patches with [micro-watershed-name = "initial" and communal-micro-watershed? = true]
    set color 0
  ]

 ask patches with [slope <= 30] [set owned-by min-one-of farmers [distance myself]]

 ask farmers [
    set own-farmland patches with [owned-by = myself]
    set education random-normal average-education 2.42
    set extent-off-farm-participation random-normal average-extent-off-farm-participation 4.34
    set perceived-performance-kebele-administrator random-normal average-perceived-performance-kebele-administrator 2.65
    set degree-participation-local-organizations random-normal average-degree-participation-local-organizations 1.11
    set perception-watershed random-normal average-perception-watershed 1.3
    set income random-normal average-income 10980
    set social-capital random-normal average-social-capital 1.35
    if membership-watershed-association = true [
    set commitment-member-micro-watershed random-normal average-commitment-member-micro-watershed 1.6
    ]
    set measure "no-measure"
  ]
end

;initialize case study data
to Case-study:Ararso-Bero
    set average-education 1.42
    set average-extent-off-farm-participation 4.96
    set average-degree-participation-local-organizations 2.8
    set average-perceived-performance-kebele-administrator 7.72
    set average-income 7176
    set average-social-capital 7.42
    set average-perception-watershed 7.5
    set proportion-of-members-watershed 0.1
    set average-commitment-member-micro-watershed 4

    set commitment-of-kebele-administrators 7
    set commitment-of-extension-workers 5
    set number-of-extension-workers 2

    set num-communal-micro-watershed 4
    set initial-length-SWC-communal-land 11.37
    set num-farmland-micro-watershed 0
    set initial-length-SWC-farmland 0
    set average-quality-SWC 4.75
    set case-study-name "Ararso-Bero"
end

to Case-study:Sara-Areda
    set average-education 1.32
    set average-extent-off-farm-participation 1.56
    set average-degree-participation-local-organizations 3.27
    set average-perceived-performance-kebele-administrator 7.55
    set average-social-capital 8.13
    set average-income 12747
    set average-perception-watershed 9.61
    set proportion-of-members-watershed 0.132
    set average-commitment-member-micro-watershed 5

    set commitment-of-kebele-administrators 7
    set commitment-of-extension-workers 5
    set number-of-extension-workers 2

    set num-communal-micro-watershed 5
    set initial-length-SWC-communal-land 5.74
    set num-farmland-micro-watershed 0
    set initial-length-SWC-farmland 0
    set average-quality-SWC 6.17
    set case-study-name "Sara-Areda"
end

to Case-study:Qachachule-Guja
    set average-education 2.12
    set average-extent-off-farm-participation 0.67
    set average-degree-participation-local-organizations 2.19
    set average-perceived-performance-kebele-administrator 4.02
    set average-social-capital 6.69
    set average-income 19023
    set average-perception-watershed 7.64
    set proportion-of-members-watershed 0
    set average-commitment-member-micro-watershed 4

    set commitment-of-kebele-administrators 5
    set commitment-of-extension-workers 4
    set number-of-extension-workers 1

    set num-communal-micro-watershed 3
    set initial-length-SWC-communal-land 6.96
    set num-farmland-micro-watershed 2
    set initial-length-SWC-farmland 5.79
    set average-quality-SWC 4.95
    set case-study-name "Qachachule-Guja"
end

;double checking labelling of run using average-education
to set-case-study-name
  if average-education = 1.42 [ set case-study-name "Ararso-Bero" ]
  if average-education = 1.32 [ set case-study-name "Sara-Areda" ]
  if average-education = 2.12 [ set case-study-name "Qachachule-Guja" ]
end

;;;;;;;;;;;;;;;;GO;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;GO;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;GO;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
 ; stop at the given number of time step
 if pause-at >= 0 and ticks >= pause-at [stop]
 if not any? patches with [pcolor = orange] [stop]

 ;update income and off-farm participation based on the availability of alternative sources of livelihood
 ;1000 and 5 are maximum income-alternative-livelihood and maximum possible reduction in extent-off-farm-participation respectively
 ask farmers [if income <= income-poor-threshold [
    set income income + income-alternative-livelihood
    set extent-off-farm-participation extent-off-farm-participation - ((income-alternative-livelihood) / 1000 ) * 5 ]
       if extent-off-farm-participation < 0 [set extent-off-farm-participation 0]
 ]

 select-micro-watersheds
 participate-in-campaign-works
 make-maintenance
 update-plotting
 tick
end

;;;;;;;;;;;;;SELECTION;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;SELECTION;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;SELECTION;;;;;;;;;;;;;;;;;;;;;;

to select-micro-watersheds

 ;to select micro-watersheds, agents (turtles) meet at the center
 ask extension-workers [
    if commitment-of-extension-workers >= extension-workers-move-selection-threshold [
      move-to patch 0 0]
  ]
 ask kebele-administrators [
    if commitment-of-kebele-administrators >= kebele-administrators-move-selection-threshold [
      move-to patch 0 0]
  ]

 ;extension workers improve perception of farmers through awareness raising in the meeting
 ask farmers [if perception-watershed >= perception-watershed-move-selection [
    move-to patch 0 0
    ifelse commitment-of-extension-workers >= extension-workers-selection-threshold
      [set perception-watershed perception-watershed + 0.1]
      [set perception-watershed perception-watershed]
     ]
  ]


  ;farmers are expected to first select fields with highest slope
 let mean-perception-watershed mean [perception-watershed] of farmers
 let highest-slope-communal max-one-of patches with [pcolor = cyan] [slope]
 let highest-slope-farm max-one-of patches with [pcolor = orange] [slope]

  ;kebele-administrators directly influence the decision of farmers
ifelse (any? patches with [pcolor = cyan] and mean-perception-watershed >= perception-watershed-selection-threshold) or
          (any? patches with [pcolor = cyan] and commitment-of-kebele-administrators >= kebele-administrators-selection-threshold)
          [ask highest-slope-communal [set communal-micro-watershed? true
                                       set micro-watershed-name ticks
                                       set pcolor lime
          ask neighbors4 [ask patches with [pcolor = cyan] in-radius 5
                                      [set communal-micro-watershed? true
                                       set micro-watershed-name ticks
                                       set pcolor lime]
      ]
    ]
  ]

         [ask highest-slope-farm [set farmland-micro-watershed? true
                                  set micro-watershed-name ticks
                                  set pcolor gray
          ask neighbors4 [ask patches with [pcolor = orange] in-radius 5
                                 [set farmland-micro-watershed? true
                                  set micro-watershed-name ticks
                                  set pcolor gray]
      ]
    ]
  ]


  ask farmers [move-to one-of own-farmland]
end

;;;;;;;;;;;;;;CAMPAIGN;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;CAMPAIGN;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;CAMPAIGN;;;;;;;;;;;;;;;;;;;;;;;

to participate-in-campaign-works
;to participate in campaign works, agents (turtles) move to the newly selected micro-watershed
ask extension-workers [
    if commitment-of-extension-workers >= extension-workers-move-campaign-threshold [
    move-to one-of patches with [micro-watershed-name = ticks]
    ]
  ]

ask farmers [
    determine-campaign-participation
    update-lengths-SWC-campaign
    update-perception-watershed-and-social-capital-due-to-campaign
    update-income-due-to-campaign
    update-perceived-performance-kebele-administrator-due-to-campaign
  ]

ask kebele-administrators [
    if commitment-of-kebele-administrators >= kebele-administrators-move-campaign-threshold [
    move-to one-of patches with [micro-watershed-name = ticks]
    update-new-members-association
    ]
  ]

ask farmers with [campaign-participation > 0] [move-to one-of own-farmland]
end

to determine-campaign-participation
set campaign-participation perceived-performance-kebele-administrator * w-perceived-performance-kebele-administrator-campaign +
    (10 - extent-off-farm-participation) * w-off-farm-participation-campaign +
    (10 - distance-micro-watershed-campaign) * w-distance-watershed-campaign +
    education * w-education-campaign +
    degree-participation-local-organizations * w-degree-participation-local-organizations-campaign +
    social-capital * w-social-capital-campaign +
    perception-watershed * w-perception-watershed-campaign

; campaign participation is higher for members of micro-watershed associations
if membership-watershed-association = true and commitment-member-micro-watershed <= min-members-commitment-threshold
   [set campaign-participation campaign-participation + 0.1]
if membership-watershed-association = true and (commitment-member-micro-watershed > min-members-commitment-threshold and commitment-member-micro-watershed < max-members-commitment-threshold)
   [set campaign-participation campaign-participation + 0.2]
if membership-watershed-association = true and commitment-member-micro-watershed >= max-members-commitment-threshold
   [set campaign-participation campaign-participation + 0.3]

;farmers copy campaign participation of a neighbor with highest awareness
let neighbor-farmers farmers in-radius 1
if perception-watershed >= perception-influence-neighbor-threshold [ask neighbor-farmers [
    set campaign-participation [campaign-participation ] of myself ]
  ]
if campaign-participation > 10 [set campaign-participation 10]
end

to-report distance-micro-watershed-campaign
report distance one-of patches with [micro-watershed-name = ticks] / 3
if distance-micro-watershed-campaign > 10 [ report 10 ]
end

to update-lengths-SWC-campaign
if campaign-participation > 0 [move-to one-of patches with [micro-watershed-name = ticks]

;a farmer will construct 0.003 km for each campaign participation, which is assumed to be 3 work days
let lengths-SWC-campaign campaign-participation * 0.003
let total-lengths-SWC-campaign sum [lengths-SWC-campaign] of farmers
let communal-SWC-cover-campaign (0.001 * total-lengths-SWC-campaign * 100 * 4) / 0.15
let farmland-SWC-cover-campaign (0.001 * total-lengths-SWC-campaign * 100 * 4) / 0.11

;maximum SWC density per micro-watershed
let maximum-SWC-denisty (count patches with [micro-watershed-name = ticks])
if communal-SWC-cover-campaign >= maximum-SWC-denisty [set communal-SWC-cover-campaign maximum-SWC-denisty]
if farmland-SWC-cover-campaign >= maximum-SWC-denisty [set farmland-SWC-cover-campaign maximum-SWC-denisty]

ifelse slope > 30 [
   ask n-of communal-SWC-cover-campaign patches with [micro-watershed-name = ticks ]
    [ifelse any? extension-workers in-radius 2
      [set quality-SWC 10 set pcolor 130 set land-use "communal-land" set communal-micro-watershed? true set communal-SWC-cover? true]
      [set quality-SWC 9 set pcolor 131 set land-use "communal-land" set communal-micro-watershed? true set communal-SWC-cover? true]]
  ]

 [ask n-of farmland-SWC-cover-campaign patches with [micro-watershed-name = ticks]
    [ifelse any? extension-workers in-radius 2
      [set quality-SWC 10 set pcolor 130 set land-use "farmland" set farmland-micro-watershed? true set farmland-SWC-cover? true]
      [set quality-SWC 9 set pcolor 131 set land-use "farmland" set farmland-micro-watershed? true set farmland-SWC-cover? true]]
  ]
]
end

to update-perception-watershed-and-social-capital-due-to-campaign
let distance-from-average-participation campaign-participation - mean [campaign-participation] of farmers

;there is 90% chance that kebele administrator take measures that influence perception-watershed and social-capital
if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
 random 100 < chance-measure-campaign and
  measure = "no-measure" and
  distance-from-average-participation > 2
    [set measure "praise"
     set perception-watershed perception-watershed
     set social-capital social-capital + 0.5
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
   random 100 < chance-measure-campaign and
  measure = "no-measure" and
  (distance-from-average-participation >= -2 and distance-from-average-participation <= 2)
    [set measure "no-measure"
     set perception-watershed perception-watershed
     set social-capital social-capital
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "no-measure" and
  distance-from-average-participation < -2
     [set measure "aware"
      set perception-watershed perception-watershed + 0.1
      set social-capital social-capital - 0.25
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
   random 100 < chance-measure-campaign and
  measure = "aware" and
  distance-from-average-participation > 2
     [set measure "praise"
     set perception-watershed perception-watershed
     set social-capital social-capital + 0.5
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "aware" and
  (distance-from-average-participation >= -2 and distance-from-average-participation <= 2)
    [set measure "no-measure"
     set perception-watershed perception-watershed
     set social-capital social-capital
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "aware" and
  distance-from-average-participation < -2
     [set measure "reprimand"
      set perception-watershed perception-watershed + 0.2
      set social-capital social-capital - 0.5
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "reprimand" and
  distance-from-average-participation > 2
     [set measure "praise"
      set perception-watershed perception-watershed
      set social-capital social-capital + 0.5
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "reprimand" and
  (distance-from-average-participation >= -2 and distance-from-average-participation <= 2)
    [set measure "no-measure"
     set perception-watershed perception-watershed
     set social-capital social-capital
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "reprimand" and
  distance-from-average-participation < -2
    [set measure "punish"
     set perception-watershed perception-watershed + 0.3
     set social-capital social-capital - 0.75
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "punish" and
  distance-from-average-participation > 2
    [set measure "praise"
     set perception-watershed perception-watershed
     set social-capital social-capital + 0.5
  ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "punish" and
  (distance-from-average-participation >= -2 and distance-from-average-participation <= 2)
    [set measure "no-measure"
     set perception-watershed perception-watershed
     set social-capital social-capital
   ]

if commitment-of-kebele-administrators > kebele-administrators-move-campaign-threshold and
  random 100 < chance-measure-campaign and
  measure = "reprimand" and
  distance-from-average-participation < -2
    [set measure "punish"
     set perception-watershed perception-watershed + 0.3
     set social-capital social-capital - 0.75
   ]

if perception-watershed < 0 [set perception-watershed 0]
if perception-watershed > 10 [set perception-watershed 10]

if social-capital < 0 [set social-capital 0]
if social-capital > 10 [set social-capital 10]
end

to update-income-due-to-campaign
 ;since farmers participate without any form of remuneration
 if measure = "punish" [set income income - (campaign-participation-cost + campaign-punishment-cost)]
 if measure != "punish" [set income income - (campaign-participation-cost)]
end

to-report campaign-participation-cost
;10 is the highest level of campaign participation
report (campaign-participation / 10) * maximum-participation-cost
end

to-report campaign-punishment-cost
;10 is the highest level of campaign participation
report maximum-punishment - ((campaign-participation / 10) * maximum-punishment)
end

to update-perceived-performance-kebele-administrator-due-to-campaign
 ;since farmers assess commitment of kebele administrators and previous campaign participation, range 0 to 10
 let kebele-performance-campaign (commitment-of-kebele-administrators + mean [campaign-participation] of farmers) / 2
 if kebele-performance-campaign >= 8 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator + 0.2]
 if kebele-performance-campaign >= 6 and kebele-performance-campaign <= 7 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator + 0.1]
 if kebele-performance-campaign >= 4 and kebele-performance-campaign <= 5 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator - 0.1]
 if kebele-performance-campaign <= 3 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator - 0.2]

 if perceived-performance-kebele-administrator < 0 [set perceived-performance-kebele-administrator 0]
 if perceived-performance-kebele-administrator > 10 [set perceived-performance-kebele-administrator 10]
end

to update-new-members-association
;kebele administrators establish an association when the new micro-watershed is on communal land
if communal-micro-watershed? = true and micro-watershed-name = ticks [
    ifelse count farmers with [membership-watershed-association = false ] >= 30 [
      ask n-of n-new-members-association farmers with [membership-watershed-association = false ] [
        set membership-watershed-association true
        set own-watershed patches with [micro-watershed-name = ticks and communal-micro-watershed? = true]
        set commitment-member-micro-watershed random-normal average-commitment-member-micro-watershed 1.6
        set color 0]
    ]

     [ask farmers with [membership-watershed-association = false ] [
       set membership-watershed-association true
       set own-watershed patches with [micro-watershed-name = ticks and communal-micro-watershed? = true]
       set color 0]
    ]
  ]
end

;;;;;;;;;;;;;;;MAINTENANCE;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;MAINTENANCE;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;MAINTENANCE;;;;;;;;;;;

to make-maintenance
ask farmers [
    determine-maintenance-participation
    update-total-lengths-SWC
    update-total-perception-watershed-and-social-capital
    update-total-income
    update-off-farm-participation
    update-commitment-member-micro-watershed
    update-perceived-performance-kebele-administrator-maintenance
  ]

ask patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true] [decay]

ask extension-workers [
    if commitment-of-extension-workers >= extension-workers-move-maintenance-threshold [
    move-to one-of patches with [communal-micro-watershed? = true or farmland-micro-watershed? = true]
    ]
  ]

ask kebele-administrators [
    if commitment-of-kebele-administrators >= kebele-administrators-move-maintenance-threshold [
    move-to one-of patches with [communal-micro-watershed? = true or farmland-micro-watershed? = true]
    ]
  ]

ask farmers with [maintenance-participation >= maintenance-threshold or maintenance-participation <= demolition-threshold]
  [move-to one-of own-farmland]
end

to determine-maintenance-participation
  ;involves labor contribution, strictly observing rules and regulations, and
  ;protecting micro-watersheds from disturbances
if membership-watershed-association = true and any? own-watershed with [communal-SWC-cover? = true] [
    set maintenance-participation perceived-performance-kebele-administrator * w-perceived-performance-kebele-administrator-maintenance +
        (10 - extent-off-farm-participation) * w-off-farm-participation-maintenance +
        (10 - distance-own-watershed-maintenance) * w-distance-watershed-maintenance +
        degree-participation-local-organizations * w-degree-participation-local-organizations-maintenance +
        perception-watershed * w-perception-watershed-maintenance]

  ;non-members also make maintenance decision
if membership-watershed-association = false and any? patches with [communal-SWC-cover? = true]
    [set maintenance-participation perceived-performance-kebele-administrator * w-perceived-performance-kebele-administrator-maintenance +
        (10 - extent-off-farm-participation) * w-off-farm-participation-maintenance +
        (10 - distance-communal-watershed-maintenance) * w-distance-watershed-maintenance +
        degree-participation-local-organizations * w-degree-participation-local-organizations-maintenance +
        perception-watershed * w-perception-watershed-maintenance]

;maintenance participation is higher for members of micro-watershed associaions
if membership-watershed-association = true and commitment-member-micro-watershed <= min-members-commitment-threshold
   [set maintenance-participation maintenance-participation + 0.1]
if membership-watershed-association = true and (commitment-member-micro-watershed > min-members-commitment-threshold and commitment-member-micro-watershed < max-members-commitment-threshold)
   [set maintenance-participation maintenance-participation + 0.2]
if membership-watershed-association = true and commitment-member-micro-watershed >= max-members-commitment-threshold
   [set maintenance-participation maintenance-participation + 0.3]

if maintenance-participation > 10 [ set maintenance-participation 10]
end

to-report distance-own-watershed-maintenance
;refers to the distance between own-farmland and own-watershed
report distance one-of own-watershed with [communal-SWC-cover? = true] / 3
if distance-own-watershed-maintenance > 10 [report 10]
end

to-report distance-communal-watershed-maintenance
report distance one-of patches with [communal-SWC-cover? = true] / 3
if distance-communal-watershed-maintenance > 10 [report 10]
end

to update-total-lengths-SWC
;farmers whose maintenance-participation is between 3 and 8 will ignore SWC structures
if maintenance-participation >= maintenance-threshold [maintain]
if maintenance-participation <= demolition-threshold [demolish]
end

to maintain
;farmers first maintain SWC with lower quality
;labor contribution for maintenance of SWC on communal land is carried out only by members of micro-watershed associations
if membership-watershed-association = true and any? own-watershed with [communal-SWC-cover? = true] [
    move-to min-one-of own-watershed with [communal-SWC-cover? = true] [quality-SWC]
    ask own-watershed with [communal-SWC-cover? = true] in-radius 0.5 [
      ifelse any? extension-workers in-radius 2 [set quality-SWC 10 set pcolor 130]
                                                [set quality-SWC 9 set pcolor 131]]
;members ensure area closure or guard micro-watersheds on communal land, but first own-watershed
    ask farmers with [maintenance-participation <= demolition-threshold] in-radius 2 [
     move-to one-of own-farmland
     set social-capital social-capital - 0.5]
  ]

;highly motivated non-members also ensure area closure or guard micro-watersheds on communal land
if membership-watershed-association = false [
    move-to one-of patches with [communal-SWC-cover? = true]
    ask farmers with [maintenance-participation <= demolition-threshold] in-radius 2 [
     move-to one-of own-farmland
     set social-capital social-capital - 0.5]
  ]

;each farmer is responsible for the maintenance of his/her farmland
if any? own-farmland with [farmland-SWC-cover? = true] [
    move-to min-one-of own-farmland with [farmland-SWC-cover? = true] [quality-SWC]
    ask own-farmland with [farmland-SWC-cover? = true] in-radius 0.5 [
      ifelse any? extension-workers in-radius 2 [set quality-SWC 10 set pcolor 130]
                                                [set quality-SWC 9 set pcolor 131]
    ]
  ]
end

to demolish
; farmers first demolish SWC with higher quality
if any? patches with [communal-SWC-cover? = true and quality-SWC > 0] [
     move-to max-one-of patches with [communal-SWC-cover? = true] [quality-SWC]
     ask patches with [communal-SWC-cover? = true] in-radius 0.5 [set quality-SWC 0 set pcolor 139.9 ]
  ]

if any? own-farmland with [farmland-SWC-cover? = true and quality-SWC > 0] [
    move-to max-one-of own-farmland with [farmland-SWC-cover? = true] [quality-SWC]
    ask patches with [farmland-SWC-cover? = true] in-radius 0.5 [set quality-SWC 0 set pcolor 139.9]
  ]
end

to decay
 ;patch procedure, SWC structures that are ignored will decay
 if quality-SWC > 0  [set quality-SWC quality-SWC - 1
                      set pcolor scale-color pink quality-SWC 10 0 ]
end

to update-total-perception-watershed-and-social-capital
;there is 80% chance that Kebele administrator take measures that influence perception-watershed and social-capital
if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  maintenance-participation >= maintenance-threshold and
  membership-watershed-association = true
    [set measure "praise"
     set perception-watershed perception-watershed
     set social-capital social-capital + 0.5
  ]

  if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  maintenance-participation >= maintenance-threshold and
  any? own-farmland with [farmland-SWC-cover? = true]
    [set measure "praise"
     set perception-watershed perception-watershed
     set social-capital social-capital + 0.5
  ]

if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  (measure = "praise" or measure = "no-measure") and
  (maintenance-participation > demolition-threshold and maintenance-participation < maintenance-threshold) and
  (membership-watershed-association = true or any? own-farmland with [farmland-SWC-cover? = true])
    [set measure "aware"
     set perception-watershed perception-watershed + 0.1
     set social-capital social-capital - 0.25
  ]

if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  measure = "aware" and
  maintenance-participation > demolition-threshold and maintenance-participation < maintenance-threshold and
   (membership-watershed-association = true or any? own-farmland with [farmland-SWC-cover? = true])
    [set measure "reprimand"
     set perception-watershed perception-watershed + 0.2
     set social-capital social-capital - 0.5
  ]

if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  measure = "reprimand" and
  maintenance-participation > demolition-threshold and maintenance-participation < maintenance-threshold and
  (membership-watershed-association = true or any? own-farmland with [farmland-SWC-cover? = true])
    [set measure "punish"
     set perception-watershed perception-watershed + 0.3
     set social-capital social-capital - 0.75
  ]

if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  measure = "punish" and
  maintenance-participation > demolition-threshold and maintenance-participation < maintenance-threshold and
   (membership-watershed-association = true or any? own-farmland with [farmland-SWC-cover? = true])
    [set measure "punish"
     set perception-watershed perception-watershed + 0.3
     set social-capital social-capital - 0.75
  ]

if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  maintenance-participation <= demolition-threshold and
   (membership-watershed-association = true or any? own-farmland with [farmland-SWC-cover? = true])
    [set measure "punish"
     set perception-watershed perception-watershed + 0.3
     set social-capital social-capital - 0.75
    ]

if any? kebele-administrators in-radius 5 and
  random 100 < chance-measure-maintenance and
  maintenance-participation <= demolition-threshold
    [set measure "punish"
     set perception-watershed perception-watershed + 0.3
     set social-capital social-capital - 0.75
    ]

if perception-watershed < 0 [set perception-watershed 0]
if perception-watershed > 10 [set perception-watershed 10]

if social-capital < 0 [set social-capital 0]
if social-capital > 10 [set social-capital 10]
end

to update-total-income
update-income-due-to-maintenance
update-income-due-to-communal-land
update-income-due-to-farmland
end

to update-income-due-to-maintenance
if maintenance-participation >= maintenance-threshold [set income income - maintenance-participation-cost]
if measure = "punish"  [set income income - maintenance-punishment-cost]
end

to-report maintenance-participation-cost
;10 is maximum maintenance participation
report (maintenance-participation * maximum-participation-cost) / 10
end

to-report maintenance-punishment-cost
;10 is maximum maintenance participation
report maximum-punishment - ((maintenance-participation * maximum-punishment) / 10)
end

to update-income-due-to-communal-land
;income obtained from communal land is divided to each member of assocations
if membership-watershed-association = true and any? own-watershed with [communal-SWC-cover? = true]
  [set income-own-watershed ((count own-watershed with [quality-SWC = 10] * 100 +
                         count own-watershed with [quality-SWC = 9] * 90 +
                         count own-watershed with [quality-SWC = 8] * 80 +
                         count own-watershed with [quality-SWC = 7] * 70 +
                         count own-watershed with [quality-SWC = 6] * 60 +
                         count own-watershed with [quality-SWC = 5] * 50 +
                         count own-watershed with [quality-SWC = 4] * 40 +
                         count own-watershed with [quality-SWC = 3] * 30 +
                         count own-watershed with [quality-SWC = 2] * 20 +
                         count own-watershed with [quality-SWC = 1] * 10) /
                         count farmers with [own-watershed = [own-watershed] of myself])
  ]

set income income + income-own-watershed
end

to update-income-due-to-farmland
;farmers whose farmland is with SWC earn income
if any? own-farmland with [farmland-SWC-cover? = true]
  [set income-own-farmland  (count own-farmland with [quality-SWC = 10] * 100 +
                         count own-farmland with [quality-SWC = 9] * 90 +
                         count own-farmland with [quality-SWC = 8] * 80 +
                         count own-farmland with [quality-SWC = 7] * 70 +
                         count own-farmland with [quality-SWC = 6] * 60 +
                         count own-farmland with [quality-SWC = 5] * 50 +
                         count own-farmland with [quality-SWC = 4] * 40 +
                         count own-farmland with [quality-SWC = 3] * 30 +
                         count own-farmland with [quality-SWC = 2] * 20 +
                         count own-farmland with [quality-SWC = 1] * 10)]

set income income + income-own-farmland
end

to update-off-farm-participation
 ;income from SWC structures will minimize farmers' participation in off-farm activities in other localities
 let income-from-SWC income-own-watershed + income-own-farmland
  if income-from-SWC >= income-poor-threshold * 0 and income-from-SWC < income-poor-threshold * 0.25 [set extent-off-farm-participation extent-off-farm-participation - 0.1]
  if income-from-SWC >= income-poor-threshold * 0.25 and income-from-SWC < income-poor-threshold * 0.5 [set extent-off-farm-participation extent-off-farm-participation - 0.2]
  if income-from-SWC >= income-poor-threshold * 0.5 and income-from-SWC < income-poor-threshold * 0.75 [set extent-off-farm-participation extent-off-farm-participation - 0.3]
  if income-from-SWC >= income-poor-threshold * 0.75 and income-from-SWC < income-poor-threshold * 1 [set extent-off-farm-participation extent-off-farm-participation - 0.4]
  if income-from-SWC >= income-poor-threshold * 1 [set extent-off-farm-participation extent-off-farm-participation - 0.5]

  if extent-off-farm-participation < 0 [set extent-off-farm-participation 0]
end

to update-commitment-member-micro-watershed
;commitment is a function of income from own watershed, social capital, and
;perception of watershed degradation and future benefits of the program
let social-relation (perception-watershed + social-capital) / 2

if (membership-watershed-association = true) and (income-own-watershed >= income-poor-threshold * 0.5) and (social-relation >= max-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed + 0.3 ]

if (membership-watershed-association = true) and (income-own-watershed >= income-poor-threshold * 0.5) and (social-relation > min-social-relation-threshold and social-relation < max-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed + 0.2 ]

if (membership-watershed-association = true) and (income-own-watershed >= income-poor-threshold * 0.5) and (social-relation <= min-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed + 0.1]

if (membership-watershed-association = true) and (income-own-watershed > 0 and income-own-watershed < income-poor-threshold * 0.5) and (social-relation >= max-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed + 0.2 ]

if (membership-watershed-association = true) and (income-own-watershed > 0 and income-own-watershed < income-poor-threshold * 0.5) and (social-relation > min-social-relation-threshold and social-relation < max-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed + 0.1 ]

if (membership-watershed-association = true) and (income-own-watershed > 0 and income-own-watershed < income-poor-threshold * 0.5) and (social-relation <= min-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed ]

if (membership-watershed-association = true) and (income-own-watershed = 0) and (social-relation >= max-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed - 0.1 ]

if (membership-watershed-association = true) and (income-own-watershed = 0) and (social-relation > min-social-relation-threshold and social-relation < max-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed - 0.2 ]

if (membership-watershed-association = true) and (income-own-watershed = 0) and (social-relation <= min-social-relation-threshold)
  [set commitment-member-micro-watershed commitment-member-micro-watershed - 0.3 ]

if commitment-member-micro-watershed < 0 [set commitment-member-micro-watershed 0]
if commitment-member-micro-watershed > 10 [set commitment-member-micro-watershed 10]
end

to update-perceived-performance-kebele-administrator-maintenance
  ;farmers assess commitment of kebele administrators and previous maintenance-participation
let kebele-performance-maintenance (commitment-of-kebele-administrators + mean [maintenance-participation] of farmers) / 2
if kebele-performance-maintenance >= 8 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator + 0.2]
if kebele-performance-maintenance >= 6 and kebele-performance-maintenance <= 7 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator + 0.1]
if kebele-performance-maintenance >= 4 and kebele-performance-maintenance <= 5 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator - 0.1]
if kebele-performance-maintenance <= 3 [set perceived-performance-kebele-administrator perceived-performance-kebele-administrator - 0.2]

if perceived-performance-kebele-administrator < 0 [set perceived-performance-kebele-administrator 0]
if perceived-performance-kebele-administrator > 10 [set perceived-performance-kebele-administrator 10]
end

;;;;;;;;;;;;PLOTTING;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;PLOTTING;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;PLOTTING;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-plotting
set-current-plot "Av. campaign participation"
set-current-plot-pen "all farmers"
plot mean [campaign-participation] of farmers
set-current-plot-pen "members"
if any? farmers with [color = 0] [plot mean [campaign-participation] of farmers with [color = 0]]

set-current-plot "maintenance decisions"
set-current-plot-pen "maintain"
plot (count farmers with [maintenance-participation >= maintenance-threshold]/ count farmers ) * 100
set-current-plot-pen "ignore"
plot (count farmers with [  maintenance-participation > demolition-threshold and maintenance-participation < maintenance-threshold ] / count farmers )* 100
set-current-plot-pen "demolish"
plot (count farmers with [ maintenance-participation <= demolition-threshold ] / count farmers )* 100

set-current-plot "Area of land"
set-current-plot-pen "covered"
plot count patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true] / 4

set-current-plot-pen "with SWC"
plot count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4

set-current-plot-pen "destroyed"
plot count patches with [quality-SWC = 0] / 4

set-current-plot "Quality SWC"
set-current-plot-pen "Quality-SWC"
if any? patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true] [plot mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]]
end
@#$#@#$#@
GRAPHICS-WINDOW
567
23
1303
760
-1
-1
22.061
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
50.0

INPUTBOX
9
710
115
770
current-seed
-2.5594983E7
1
0
Number

SWITCH
9
672
114
705
new-seed?
new-seed?
0
1
-1000

BUTTON
10
224
73
257
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
145
225
205
258
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
77
224
143
257
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
12
345
229
378
initial-length-SWC-communal-land
initial-length-SWC-communal-land
0
12
11.37
1
1
NIL
HORIZONTAL

SLIDER
12
419
227
452
initial-length-SWC-farmland
initial-length-SWC-farmland
0
15
0.0
1
1
NIL
HORIZONTAL

SLIDER
274
41
544
74
number-of-farmers
number-of-farmers
100
250
180.0
10
1
NIL
HORIZONTAL

SLIDER
13
383
228
416
num-farmland-micro-watershed
num-farmland-micro-watershed
0
5
0.0
1
1
NIL
HORIZONTAL

SLIDER
12
304
229
337
num-communal-micro-watershed
num-communal-micro-watershed
0
5
4.0
1
1
NIL
HORIZONTAL

SLIDER
280
366
544
399
average-education
average-education
0
10
1.42
0.01
1
NIL
HORIZONTAL

SLIDER
272
84
544
117
average-extent-off-farm-participation
average-extent-off-farm-participation
0
10
4.96
1
1
NIL
HORIZONTAL

SLIDER
273
121
546
154
average-degree-participation-local-organizations
average-degree-participation-local-organizations
0
10
2.8
1
1
NIL
HORIZONTAL

SLIDER
275
161
545
194
average-perceived-performance-kebele-administrator
average-perceived-performance-kebele-administrator
0
10
7.72
1
1
NIL
HORIZONTAL

SLIDER
275
205
545
238
average-social-capital
average-social-capital
0
10
7.42
1
1
NIL
HORIZONTAL

SLIDER
280
402
545
435
average-perception-watershed
average-perception-watershed
0
10
7.5
0.01
1
NIL
HORIZONTAL

SLIDER
282
483
546
516
average-commitment-member-micro-watershed
average-commitment-member-micro-watershed
0
10
4.0
1
1
NIL
HORIZONTAL

SLIDER
282
520
551
553
proportion-of-members-watershed
proportion-of-members-watershed
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
285
566
547
599
income-poor-threshold
income-poor-threshold
0
1000
500.0
50
1
NIL
HORIZONTAL

SLIDER
285
603
549
636
income-alternative-livelihood
income-alternative-livelihood
0
1000
0.0
50
1
NIL
HORIZONTAL

SLIDER
9
583
232
616
commitment-of-extension-workers
commitment-of-extension-workers
0
10
5.0
1
1
NIL
HORIZONTAL

SLIDER
10
511
229
544
commitment-of-kebele-administrators
commitment-of-kebele-administrators
0
10
7.0
1
1
NIL
HORIZONTAL

INPUTBOX
120
657
232
717
pause-at
25.0
1
0
Number

PLOT
1317
73
1569
204
Av. campaign participation
time
score
0.0
25.0
0.0
10.0
true
true
"" ""
PENS
"all farmers" 1.0 0 -16383231 true "" ""
"members" 1.0 0 -14439633 true "" ""

SLIDER
282
446
544
479
n-new-members-association
n-new-members-association
0
30
10.0
5
1
NIL
HORIZONTAL

SLIDER
278
285
546
318
maximum-participation-cost
maximum-participation-cost
250
1000
600.0
50
1
NIL
HORIZONTAL

SLIDER
280
333
544
366
maximum-punishment
maximum-punishment
0
1000
600.0
50
1
NIL
HORIZONTAL

MONITOR
285
695
493
740
% members-watershed-associations
(count farmers with [color = 0] / count farmers) * 100
2
1
11

PLOT
1322
503
1850
663
Quality SWC
time
score
0.0
25.0
0.0
10.0
false
false
"" ""
PENS
"Quality-SWC" 1.0 0 -16777216 true "" ""

PLOT
1319
274
1849
437
Area of land
time 
ha
0.0
25.0
0.0
100.0
true
true
"" ""
PENS
"covered" 1.0 0 -14477296 true "" ""
"with SWC" 1.0 0 -13840069 true "" ""
"destroyed" 1.0 0 -5298144 true "" ""

MONITOR
1322
459
1851
504
quality-SWC
mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]
2
1
11

MONITOR
1318
227
1494
272
covered
count patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true] / 4
2
1
11

TEXTBOX
13
490
163
509
Kebele administrators
15
0.0
1

TEXTBOX
12
560
162
578
Extension workers 
15
0.0
1

TEXTBOX
320
18
470
37
Farmers 
15
0.0
1

TEXTBOX
16
10
166
29
1. Select case study 
15
0.0
1

TEXTBOX
13
197
163
215
2. Setup & go
14
0.0
1

BUTTON
16
29
172
62
Ararso-Bero
Case-study:Ararso-Bero
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
16
66
171
99
Sara-Areda
Case-study:Sara-Areda
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
16
101
170
134
Qachachule-Guja
Case-study:Qachachule-Guja
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
15
139
172
184
Case study
case-study-name
0
1
11

TEXTBOX
18
283
168
302
Micro-watersheds
15
0.0
1

TEXTBOX
1320
661
1843
758
----------------------------------------------------------------------Key--------------------------------------------------------\n   Turtles (agents):                                                         Environment:                                                       \n Kebele administrator (red)                                        Communal land without micro-watershed (cyan)         \n Extension workers (blue)                                         Farmland without micro-watershed (orange)\n Farmers, non-members of association (white)           Communal land with micro-watershed (Lime)  \n Farmers, members of association (black)                   Farmland with micro-watershed (gray) \n                                                                               Quality of SWC, scale color pink (lighter color lower quality)\n  
10
0.0
1

MONITOR
1682
227
1847
272
destroyed
count patches with [quality-SWC = 0] / 4
2
1
11

SLIDER
277
247
545
280
average-income
average-income
7000
25000
7176.0
1
1
NIL
HORIZONTAL

SLIDER
10
621
233
654
number-of-extension-workers
number-of-extension-workers
0
5
2.0
1
1
NIL
HORIZONTAL

MONITOR
1496
228
1681
273
with SWC
count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4
2
1
11

MONITOR
1317
27
1448
72
all
mean [campaign-participation] of farmers
2
1
11

MONITOR
1449
26
1571
71
members
mean [campaign-participation] of farmers with [color = 0]
2
1
11

MONITOR
1582
26
1665
71
maintan
count farmers with [maintenance-participation >= maintenance-threshold]
2
1
11

MONITOR
1667
26
1755
71
ignore
count farmers with [(maintenance-participation > demolition-threshold) and (maintenance-participation < maintenance-threshold)]
2
1
11

MONITOR
1757
25
1845
70
Demolish
count farmers with [maintenance-participation <= demolition-threshold]
2
1
11

PLOT
1582
75
1845
204
maintenance decisions
time
%
0.0
25.0
0.0
100.0
true
true
"" ""
PENS
"maintain" 1.0 0 -13840069 true "" ""
"ignore" 1.0 0 -7500403 true "" ""
"demolish" 1.0 0 -2674135 true "" ""

MONITOR
285
647
494
692
mean own-farmland
count patches with [land-use = \"farmland\"] / number-of-farmers
2
1
11

SLIDER
12
454
228
487
average-quality-SWC
average-quality-SWC
0
10
4.75
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

The purpose of this model is to simulate the national Campaign-Based Watershed Management (CBWM) program of Ethiopia.

The model was developed to explore conditions that enhance outcomes of the CBWM program. It analyzes the effect on the area of land covered and quality of Soil and Water Conservation (SWC) structures of (1) enhancing farmers’ awareness and motivation, (2) establishing and strengthening micro-watershed associations, (3) introducing alternative livelihood opportunities, and (4) enhancing the commitment of local government actors. 

The model was developed as part of a PhD Thesis at the Soil Physics and Land Management Group of Wageningen University, The Netherlands. 

## HOW IT WORKS

This model includes three agents (farmers, Kebele administrator, extension workers) and the physical environment that interact with each other. The physical environment is represented by patches (fields), and each field is equal to 0.25 ha. Farmers make decisions on the locations of micro-watersheds to be developed, participation in campaign works, and maintenance activities. The decisions of farmers depend on their attributes and interaction with other agents.

## HOW TO USE IT

To run the model it is essential to select a case study. This adjusts initial conditions of agents and physical environment for each case study. In addition, you may adjust number of farmers and model time step from the interface. 

Next, press setup button, and then go to run the model. 

Please note that to conduct scenario analysis you should use behaviourSpace.

## THINGS TO NOTICE

First, read keys to understand the colors that represent different agents and fields (indicated at the right-bottom of the interface). In the Netlogo world, you may inspect how the attributes of agents and fields evolve overtime. 

In addition, when the model runs watch farmers' level of participation in campaign works as well as their maintenance decisions. Also, take a look at the area of land covered with SWC structures and quality of SWC structures overtime. The monitors give actual outputs at each time step.    

You may compare case studies in the default settings and assess combinations that optimize area of land covered and quality of SWC structures. To this end, it is essential to conduct multiple runs and analyze the model outputs in Ms excel tables.

## EXTENDING THE MODEL

This model can be extended and used for scenario analysis, as well as for discussion or negotiation. For instance, you may use actual map of the case study and distribute farmers to farmland based on actual farm size of each case study. You can also make "number-of-farmers" dynamic by introducing birth, death, and migration in the model.     

## MORE INFORMATION IS NEEDED 

For more information please contact Samuel Assefa Heban at samuelheban@yahoo.com or samuel.assefaheban@wur.nl.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Calibration-AB" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1172028936"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-SA" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1992283431"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-QG" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-513980123"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Calibration-AB-Nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1281668999"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-SA-Nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2142431006"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-QG-Nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1476296119"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-AB-B" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1490243028"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibiration-SA-B" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-885866498"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-QG-B" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2006734854"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-AB-C" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-635481297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Calibration-SA-C" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-450233358"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Calibration-QG-C" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1405842095"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-AB-D" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-259529972"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-SA-D" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-436312208"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-QG-D" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="755427058"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-AB-E" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1082351868"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-SA-E" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-290591730"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-QG-E" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="99727521"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Initial-quality-AB" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1644831625"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Intial quality-SA" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1256418735"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Initial quality-QG" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1813527620"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Intial-income-AB" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1808342521"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Income-SA" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="476714060"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="1473"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Income-QG" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-337892327"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="2064"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Calibration-income-AB" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="435001320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="9510"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-income-SA" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1820167634"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="14730"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="calibration-income-QG" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="demolition-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-campaign-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-move-selection">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-campaign">
      <value value="0.096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-campaign">
      <value value="0.012"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-social-capital-campaign">
      <value value="0.085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1978670591"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-maintenance">
      <value value="0.022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-campaign">
      <value value="0.242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perceived-performance-kebele-administrator-maintenance">
      <value value="0.289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-campaign">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-perception-watershed-maintenance">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-campaign-threshold">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="20640"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extension-workers-move-selection-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-off-farm-participation-maintenance">
      <value value="0.385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-selection-threshold">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-distance-watershed-maintenance">
      <value value="0.104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perception-watershed-selection-threshold">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-education-campaign">
      <value value="0.141"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="kebele-administrators-move-maintenance-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maintenance-threshold">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="w-degree-participation-local-organizations-campaign">
      <value value="0.039"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-quality-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-415113273"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-quality-associations" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1693272493"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-quality-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1882165427"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-quality-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1541440602"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-quality-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1376221098"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-income-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1576866249"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-income-Nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1738429651"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-income-associations" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="924058110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-income-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1425093115"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-income-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1124257014"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-income-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1994789429"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-social-Nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1869659403"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-social-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1776382222"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-social-associations" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1956382317"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-social-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1913386770"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-social-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1891399159"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-social-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1691620617"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-SWC-nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1707913605"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-SWC-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-education" first="1.32" step="1" last="10"/>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1372506077"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-perception-watershed" first="9.61" step="1" last="10"/>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-SWC-association" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="n-new-members-association" first="5" step="5" last="30"/>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="9.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1594522486"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-commitment-member-micro-watershed" first="5" step="1" last="10"/>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-SWC-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <steppedValueSet variable="income-poor-threshold" first="300" step="100" last="500"/>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="829171546"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <steppedValueSet variable="income-alternative-livelihood" first="0" step="100" last="1000"/>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-SWC-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <steppedValueSet variable="commitment-of-extension-workers" first="5" step="1" last="10"/>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-extension-workers" first="2" step="1" last="5"/>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1233419629"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <steppedValueSet variable="commitment-of-kebele-administrators" first="6" step="1" last="10"/>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-SWC-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1450401243"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-SWC-associations (2)" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-391028017"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-quality-Nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="385214205"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-quality-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="568717878"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-quality-association" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1284360403"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-quality-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1083818080"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-quality-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1977793016"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-quality-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="19958919"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1067648474"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1016735587"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-934469853"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1561310184"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-association (2x)" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-894839199"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-motivation (2x)" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1181334250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-Nominal (2x)" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1355597183"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-motivation (3x)" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-503021932"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1167883331"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1147299170"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-motivation (4x)" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1236619402"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-NOMINAL (4x)" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1418057563"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-social-nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1898443742"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-social-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1970616286"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-social-association" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="731651581"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-social-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1599606589"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-social-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-888383204"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-social-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="289497273"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-SWC-nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1416761479"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-SWC-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-education" first="2.12" step="1" last="10"/>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="39519142"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-perception-watershed" first="7.64" step="1" last="10"/>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-SWC-association" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <steppedValueSet variable="n-new-members-association" first="5" step="5" last="30"/>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1530202743"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-commitment-member-micro-watershed" first="0" step="1" last="10"/>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-SWC-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <steppedValueSet variable="income-poor-threshold" first="300" step="100" last="500"/>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2025696755"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="income-alternative-livelihood" first="0" step="100" last="1000"/>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-SWC-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <steppedValueSet variable="commitment-of-extension-workers" first="4" step="1" last="10"/>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-extension-workers" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="623674511"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="commitment-of-kebele-administrators" first="5" step="1" last="10"/>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-SWC-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="9.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-501475326"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-quality-nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="409020480"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-quality-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="9.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1293281541"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-quality-association" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1623729399"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-quality-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1937933199"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-quality-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-465166465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-quality-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="9.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-244383695"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-Nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1522257910"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="9.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="991708708"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-associations" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-415721351"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1123313983"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-capacity" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="470286375"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-all" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [income] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="9.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1883175251"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-social-nominal" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-904108866"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-social-motivation" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="9.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="619360816"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-social-association" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1591866862"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-social-livelihood" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [social-capital] of farmers</metric>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-members-commitment-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-social-relation-threshold">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-753961947"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-members-commitment-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-social-relation-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-with-punishment" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.84"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="451581819"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-without-punishment" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.84"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chance-of-reward">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-368100142"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-runs" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1250268056"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-AB-SWC-Nominal" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1903019738"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-AB-nominal-quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2144294145"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-SA-nominal-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-519962244"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-SA-quality-nominal" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1247585618"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-QG-nominal-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-6523049"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-QG-quality-nominal" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-247429900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-n-new-member-Low-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-300203919"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-AB-n-new-member-high-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="615285730"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-n-member-quality-Low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="172038086"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-n-member-quality-High" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1165575591"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-participation-cost-SWC-Low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1480922145"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-participation-cost-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="503364092"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-participation-cost-quality-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1864020820"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-participation-cost-quality-High" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="22111317"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-punishment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="2015936115"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-punishment-SWC-High" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="757005236"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-punishment-quality-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1511259796"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-punishment-quality-high" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="853334320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-poor-threshold-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="30923326"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-poor-threshold-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1738501069"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-poor-threshold-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1586680264"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-poor-threshold-quality-High" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1144007296"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-number-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1859428819"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="170"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-number-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1458314477"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="190"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-number-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-420711069"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="170"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-number-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1832289855"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="190"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="329042142"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="403278067"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="931275666"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1835587769"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-demolish-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="99402243"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-demolish-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="2036081812"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-demolish-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1088574272"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-demolish-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-446646152"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-commitment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-703829717"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-commitment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1725413424"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-commitment-SWC-HGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-106417525"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-commitment-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-870516417"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-commitment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="42544724"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-commitment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1987388440"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-commitment-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-796445077"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-commitment-quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="45333437"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-social-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1934452538"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="885279105"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-social-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-789011336"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-min-social-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1235003196"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-social-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-927600685"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="931906213"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-social-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-631271992"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-max-social-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-87748715"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="388603121"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="568838753"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="2080102527"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1265720644"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="300575717"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1524437933"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-127323510"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1906755271"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="483055215"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-280932104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1991862264"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="487361072"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1042438024"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1675681447"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-2024204873"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1879939062"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-move-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1172782911"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-move-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-2047832577"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-move-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1008948698"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-move-quality-HiGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1473526725"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-155277980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1848085587"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="134527962"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-perception-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-691631130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1584149346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="464703444"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1344445385"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1839160733"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1252762620"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1060705328"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1574980530"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1530970514"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1716833684"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1628592458"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="724565715"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-KA-move-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="705582010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-campaign" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1292212825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="869638259"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1050233790"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-EW-move-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1967544478"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-W-KA-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2142500987"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="W-KA-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1858219806"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="W-KA-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1053539943"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="W-KA-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="750258450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-W-offarm-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-822541480"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-W-offarm-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="564681837"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-W-offarm-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1994378471"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-W-offarm-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1672126392"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-W-distance-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1409163910"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-W-distance-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="313373977"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-distance-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1810583468"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-distance-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-229323486"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-education-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="124641722"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-education-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="501264748"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-education-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-755169779"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-education-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1764003060"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-social-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1418184675"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-social-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1328491077"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-social-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2051684450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-social-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-789182701"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-degree-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1422057331"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-degree-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1012109939"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-degree-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="838133809"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-degree-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1808005600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-w-perception-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1882253085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-Nominal-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1595479433"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-nominal-quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-544288173"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-n-member-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="437548117"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-n-member-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-706913709"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-n-member-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-17321052"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-n-member-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1369907825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-n-member-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2043326397"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-n-member-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1258274562"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-n-member-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1057193393"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-n-member-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="116328100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-participation-cost-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1343200643"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-participation-cost-quality-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2074764052"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-participation-cost-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-688752518"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-prticipation-cost-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1580462044"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-participation-cost-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="940903003"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-participation-cost-Quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1240534942"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-participation-cost-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="581548893"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-participation-cost-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="138412396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-punishment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-20444068"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-punishment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1862049104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-punishment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1845634955"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-punishment-quality-lOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1305592797"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-punishment-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1813098748"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-punishment-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-733112908"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-punishment-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1713814390"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-punishment-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-238543936"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-punishment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1803766732"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1213432931"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-quality-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="275034545"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-SWC-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-322433579"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1307921364"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="450"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2097416310"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-income-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="119076480"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-274230419"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-income-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1906731082"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-number-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1195350018"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="170"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-number-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1754864004"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="170"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-number-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="952932806"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="170"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-number-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="266747219"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="170"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-number-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1645270816"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="190"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-number-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1642567047"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="190"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-number-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1407375207"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="190"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-number-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-708548803"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="190"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-maintenance-threshold-SW-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1632348246"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-maintenance-threshold-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1877068079"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-maintenance-threshold-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="335371927"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-maintenance-thresold-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1771540110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-maintenance-threshold-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-593407538"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-maintenane-threshold-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="385303966"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-maintenance-threshold-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1832365679"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-maintenance-threshold-Quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="893163083"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-demolish-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1045125242"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-demolish-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1739441613"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-demolish-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1368284377"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-demolish-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1619981033"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-demolish-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="98665290"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-demolish-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="711856024"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-demolish-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1949481289"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-demolish-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1064889044"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-commitment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1998943806"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-commitment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="669496224"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-commitment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="404551509"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-commitment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2114081376"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-commitment-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1634909565"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-commitment-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="590733567"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-commitment-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1714402193"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-commitment-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="250092468"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-commitment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1408775172"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-commitment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="719194026"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-commitment-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="945266780"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-commitment-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1442959190"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-commitment-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1655900699"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-commitment-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-356306864"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-commitment-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-796714344"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-commitment-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2009553008"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-social-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="480657984"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2061882243"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-social-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-990457577"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="283422913"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-social-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1558230868"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-social-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1228098677"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-social-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-167891984"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-social-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="937211349"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-min-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1302423559"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-min-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="828703757"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-social-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1041340525"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1108770771"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-social-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="666882014"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-social-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1653535147"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-social-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="453905637"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-max-social-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1323809623"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-social-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="985047111"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-max-social-quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1783136594"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-selection-SWC-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2124251250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1323975419"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1376703881"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="602083297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="438826373"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1837173458"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1961287601"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1712355646"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-607048655"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1201060407"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="621967889"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-929182391"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-586017580"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1980798839"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1805451066"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="186466739"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="447050676"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-574207937"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-558549238"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2104289792"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-kA-move-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="969306619"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="439072024"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1922173346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2018130846"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1785595670"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1190295074"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-373514979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="653462643"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1376103771"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="997645910"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-960535418"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-789902492"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1278685548"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="742258311"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-perception-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2045065569"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-perception-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="81816148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1261460346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-903922610"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-perception-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-62397992"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-perception-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1326388808"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2078629873"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2024745951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-percception-selection-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1201806637"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-perception-selection-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1142657856"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-16123666"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-perception-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-290915159"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-perception-selection-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1698822950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-perception-selection-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2041734946"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="816137567"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-kA-move-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1859881582"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1486856848"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-maintenane-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-335986261"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1391630976"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-605423865"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-987986887"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1247731413"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1789387855"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-maintenance-quality-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-797232093"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-748943226"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="836867297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2102898562"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2000731659"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1476048447"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="23732286"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-300274334"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1426187299"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-99065849"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1128542228"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-330753907"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="233267968"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1857350490"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-move-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1171394476"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2017269955"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-move-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1791389909"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-274725269"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1488168623"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1577526959"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1024411454"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-832242591"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-EW-move-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1269212244"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-camapign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-957621036"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-EW-move-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1684115603"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-campaign" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1940832684"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-Quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-393142417"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-quality-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="373315731"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1793617081"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="987833992"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="76218415"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1274799623"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1204414098"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1067595860"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1068576525"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="2115007432"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-527391048"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="970369684"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-chance-reward-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-2042853277"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-923816408"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1031278104"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-chance-reward-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-841757004"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-neighbor-influence-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-92067790"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-neighbor-influence-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-905732729"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-neighbor-influence-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-201380652"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-neighbor-influence-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1280399405"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-neighbor-influence-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1705480668"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-neighbor-influence-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1927494860"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-neighbor-influence-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-507883557"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-neighbor-influence-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="2006721719"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1082427544"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-KA-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1854138816"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-KA-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="447519073"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-KA-campaign-quality- LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1938402370"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-KA-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-19660034"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-KA-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-3131800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-KA-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1528814138"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-KA-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1602541448"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-offarm-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-757211994"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-offarm-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-350805075"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-offarm-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="609537392"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-offarm-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1237184096"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-offarm-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-649608"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-offarm-campaign-Quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-254742330"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-offarm-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1595644237"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-offarm-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1895311504"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1496727112"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1992526670"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1075074380"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="588981749"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1309009754"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="2011025891"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-campaign-quality-High" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-31251489"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-376226470"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1759876337"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-education-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1649154024"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-education-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1784697235"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-education-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1084925143"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-education-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1223415924"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-education-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1125551057"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-education-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-729006569"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-education-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-556644859"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-education-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1460289950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-social-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="867579102"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-social-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-91081841"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-social-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-750270444"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-social-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1439178465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-social-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-2033812046"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-social-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1757256054"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-social-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="128280120"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-social-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1450994675"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="660283874"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1522358541"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="572712550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1159139714"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-campaign-SWC-HiGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1527765685"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-degree-campaign-quality-High" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1434905249"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="823820086"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-campaign-Quality-High" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1822496653"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-campaign-quality-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1685783964"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1930633744"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-campaign-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="138745694"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1515410063"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-campaign-quality-low" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1683121967"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="1883999358"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-campaign-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-56496272"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-campaign-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="747937449"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-campaign-Quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1528579022"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-campaign-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="current-seed">
      <value value="-1663077235"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-W-KA-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1719490578"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-KA-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-80085592"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-KA-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2002007245"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-KA-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1816484506"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-KA-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1562588967"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-KA-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="797051312"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-KA-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1102906066"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-KA-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-733944147"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-offarm-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1197410815"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-offarm-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="667176390"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-offarm-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1346637490"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-offarm-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-815116119"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-offarm-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-860333731"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-offarm-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="161015604"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-offarm-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1618090949"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-offarm-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-158818511"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1337960321"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="224284778"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-635981552"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-91763515"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1045870153"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-distance-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1181338582"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="697344084"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-distance-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1306774903"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-151985917"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1721130847"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-493531840"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-832150382"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="703997623"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-degree-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1592230833"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1042628798"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-degree-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1031680780"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-pereption-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1301060535"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1944003234"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-maintenance-SWC-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1819575930"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-maintenance-quality-LOW" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-680818196"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1842921444"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-w-perception-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="427277216"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-maintenance-SWC-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1381128405"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-w-perception-maintenance-quality-HIGH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1246392014"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-default-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-64630428"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-motivation-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-164484291"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.84"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-assoications-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="139406125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-livelihood-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2105620594"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-capacity-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1061946695"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-motivation-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2030963749"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-capacity-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="16697788"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-scenario-all-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1927935074"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="7176"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.84"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-default-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="20048580"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-default-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-340181577"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-motivation-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="531563459"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-motivation-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-59517685"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-associations-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-734330679"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-associations-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="2085463435"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-livelihood-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-667694710"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-livelihood-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="316576259"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-capacity-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="663296689"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-capacity-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1170172860"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-ALL-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-92591812"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-scenario-capacity-ALL" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-320112837"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="12747"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="6.17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-scenario-default-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-600246249"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-scenario-default-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="336815208"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-scenario-motivation-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1007926292"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="4.24"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-scenario-assoication-SWC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0] / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="812347692"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-scenario-associations-Quality" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="25"/>
    <metric>mean [quality-SWC] of patches with [communal-SWC-cover? = true or farmland-SWC-cover? = true]</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="1451509054"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="19023"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="4.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-calibration-100x" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="144606949"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="9510"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="11.37"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-calibration-100x" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-234942377"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="14730"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="5.74"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-calibiration-100x" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1526999419"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="5.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="20640"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="6.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-calibiration-100X" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="9510"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1689029845"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-calibration-100X" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="14730"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.132"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-914549210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-calibiration-100X" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="20640"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="200422669"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-calibration-100XX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="14730"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-51656004"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-calibiration-100XXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="9.61"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="1.56"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="8.13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="3.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="14730"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-1812822399"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AB-calibiration-100XX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="7.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="4.96"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="7.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="9510"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="1.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-2041271431"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QG-calibiration-100XX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>(count patches with [(communal-SWC-cover? = true or farmland-SWC-cover? = true) and quality-SWC != 0]) / 4</metric>
    <enumeratedValueSet variable="average-perceived-performance-kebele-administrator">
      <value value="4.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-perception-watershed">
      <value value="7.64"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-extent-off-farm-participation">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmland-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-social-capital">
      <value value="6.69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-participation-local-organizations">
      <value value="2.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-farmland">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-communal-micro-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-farmers">
      <value value="180"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-income">
      <value value="20640"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-extension-workers">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-new-members-association">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-extension-workers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-alternative-livelihood">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pause-at">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-education">
      <value value="2.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-poor-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commitment-of-kebele-administrators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-punishment">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-of-members-watershed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-commitment-member-micro-watershed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-quality-SWC">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-length-SWC-communal-land">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="current-seed">
      <value value="-969797308"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-participation-cost">
      <value value="600"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
